@@ -7,10 +7,8 @@
 
 #pragma once
 
-#include <QDialog>
-
-#include "kpimtextedit/plaintexteditor.h"
 #include "kpimtextedit_private_export.h"
+#include <QDialog>
 
 namespace KPIMTextEdit
 {
@@ -21,7 +19,7 @@ class KPIMTEXTEDIT_TESTS_EXPORT InsertHtmlDialog : public QDialog
 public:
     explicit InsertHtmlDialog(QWidget *parent = nullptr);
     ~InsertHtmlDialog() override;
-    Q_REQUIRED_RESULT QString html() const;
+    [[nodiscard]] QString html() const;
     void setSelectedText(const QString &str);
 
 private:
